/****************************************************************************
** Meta object code from reading C++ file 'spellcheckdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktexteditor-6.26.0/src/spellcheck/spellcheckdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'spellcheckdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20KateSpellCheckDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto KateSpellCheckDialog::qt_create_metaobjectdata<qt_meta_tag_ZN20KateSpellCheckDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KateSpellCheckDialog",
        "spellcheckFromCursor",
        "",
        "spellcheckSelection",
        "spellcheck",
        "KTextEditor::Cursor",
        "from",
        "to",
        "misspelling",
        "corrected",
        "performSpellCheck",
        "KTextEditor::Range",
        "range",
        "installNextSpellCheckRange",
        "cancelClicked",
        "objectDestroyed",
        "object",
        "languageChanged",
        "language"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'spellcheckFromCursor'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'spellcheckSelection'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'spellcheck'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'spellcheck'
        QtMocHelpers::SlotData<void(const KTextEditor::Cursor, const KTextEditor::Cursor)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Slot 'spellcheck'
        QtMocHelpers::SlotData<void(const KTextEditor::Cursor)>(4, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'misspelling'
        QtMocHelpers::SlotData<void(const QString &, int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'corrected'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'performSpellCheck'
        QtMocHelpers::SlotData<void(KTextEditor::Range)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'installNextSpellCheckRange'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cancelClicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'objectDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 },
        }}),
        // Slot 'languageChanged'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KateSpellCheckDialog, qt_meta_tag_ZN20KateSpellCheckDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KateSpellCheckDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KateSpellCheckDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KateSpellCheckDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20KateSpellCheckDialogE_t>.metaTypes,
    nullptr
} };

void KateSpellCheckDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KateSpellCheckDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->spellcheckFromCursor(); break;
        case 1: _t->spellcheckSelection(); break;
        case 2: _t->spellcheck(); break;
        case 3: _t->spellcheck((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 4: _t->spellcheck((*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[1]))); break;
        case 5: _t->misspelling((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->corrected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->performSpellCheck((*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[1]))); break;
        case 8: _t->installNextSpellCheckRange(); break;
        case 9: _t->cancelClicked(); break;
        case 10: _t->objectDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 11: _t->languageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KateSpellCheckDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KateSpellCheckDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20KateSpellCheckDialogE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KateSpellCheckDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
